@@ -1,4 +1,4 @@
-__version__ = '1.0.6'
+__version__ = '1.0.7'
 __packagename__ = 'HotStepper'
 __author__ = 'Jackson Storm'
 
@@ -8,3 +8,6 @@ import hotstepper.utilities.helpers as utilities
 from hotstepper.core.Step import Step
 from hotstepper.core.Steps import Steps
 
+import warnings
+warnings.filterwarnings("ignore")
+
